<div class="panel panel-default">
    <div class="panel-body">
        <h1>
            Alerts
        </h1>
        <h3>
            Success alerts
        </h3>
        <pre><code>alert:success:This is a success alert! Yes, you can also use \n in here.</code></pre>
        <h4>
            Example
        </h4>
        <div class="alert alert-success" role="alert">This is a success alert! Yes, you can also use <br> in here.</div>
        <hr>
        <h3>
            Info alerts
        </h3>
        <pre><code>alert:info:This is a info alert! Yes, you can also use \n in here.</code></pre>
        <h4>
            Example
        </h4>
        <div class="alert alert-info" role="alert">This is a info alert! Yes, you can also use <br> in here.</div>
        <hr>
        <h3>
            Warning alerts
        </h3>
        <pre><code>alert:warning:This is a warning alert! Yes, you can also use \n in here.</code></pre>
        <h4>
            Example
        </h4>
        <div class="alert alert-warning" role="alert">This is a warning alert! Yes, you can also use <br> in here.</div>
        <hr>
        <h3>
            Danger alerts
        </h3>
        <pre><code>alert:danger:This is a danger alert! Yes, you can also use \n in here.</code></pre>
        <h4>
            Example
        </h4>
        <div class="alert alert-danger" role="alert">This is a danger alert! Yes, you can also use <br> in here.</div>
    </div>
</div>