<div class="panel panel-default">
    <div class="panel-body">
        <h1>
            Blocks
        </h1>
        <h3>
            Blockquote
        </h3>
        <p>
            Blockquotes are used to indicate quoted or referenced text, often used for citations, excerpts, or highlighting important information. They are created by prefixing the text with a greater-than symbol (>), followed by a space.
        </p>
        <pre><code>> blockquote</code></pre>
        <h4>
            Examples
        </h4>
        <blockquote>
            <p>blockquote</p>
        </blockquote>
        <hr>

        <h3>
            Code
        </h3>
        <p>
            Code Blocks () or (~~~): Code blocks are used to display lines or blocks of code without any formatting or interpretation. This block is not effected by <code>\n</code>.
        </p>
        
        <pre><code>`code`</code></pre>
        <h4>
            Examples
        </h4>
        <p><code>code</code></p>
        <hr>

        <h3>
            Code (Full width)
        </h3>
        <pre><code>```
code
```</code></pre>
        <h4>
            Examples
        </h4>
        <pre><code>code</code></pre>
    </div>
</div>