<div class="panel panel-default">
    <div class="panel-body">
        <h1>
            Images
        </h1>
        <p>
            Images can be added to Markdown documents by using the following syntax: an exclamation mark (!), followed by the alt text (which describes the image), enclosed in square brackets ([]), and the URL or path to the image enclosed in parentheses (()).
        </p>
        <pre><code>![Keepstar](https://images.evetech.net/types/35834/render?size=128)</code></pre>
        <p><img src="https://images.evetech.net/types/35834/render?size=128" alt="Keepstar"></p>
    </div>
</div>